Dependency Parsing
===================

.. note::

    This tutorial is available as an IPython notebook
    `here <https://github.com/huseinzol05/Malaya/tree/master/example/dependency>`_.

.. include:: load-dependency.rst
